@@ -7,6 +7,7 @@ use std::{
 use bytes::Bytes;
 use exocore_core::{
     cell::{CellNodeRole, FullCell, LocalNode, Node, NodeId},
+    dir::ram::RamDirectory,
     framing::{
         CapnpFrameBuilder, FrameBuilder, FrameReader, MultihashFrameBuilder, SizedFrameBuilder,
         TypedCapnpFrame,
@@ -107,9 +108,9 @@ impl EngineTestCluster {
                 name: format!("test-node-{}", i),
                 ..LocalNode::generate().config().clone()
             };
-            let local_node = LocalNode::new_from_config(node_config).unwrap();
+            let local_node = LocalNode::from_config(RamDirectory::default(), node_config).unwrap();
 
-            let cell = FullCell::generate(local_node.clone());
+            let cell = FullCell::generate(local_node.clone()).unwrap();
             cells.push(cell.clone());
 
             nodes_index.insert(local_node.id().clone(), i);
